| scaledBound | R Documentation |
It calculates widened bound for scaled average bioequivalence.
scaledBound(CV = 40, k = 0.76, digits = 4)
CV |
coefficient of variation in percent |
k |
0.76 is for EMA and Korea MFDS. US FDA uses 0.893. When CV is 30%, bound becomes (0.8, 1.25). Most regulatory bodies do not use a more accurate value. |
digits |
Korea MFDS use 4 digits only, while other regulatory bodies use more decimal values. |
CV must be larger than 30%. For EMA and Korea MFDS (k = 0.76) the CV is capped at 50% for the widening, while US FDA (k = 0.893) is not capped. US FDA uses this widened bound for both AUClast and Cmax, while EU EMA and Korea MFDS use this for Cmax only.
widened bound for scaled average bioequivalence
Kyun-Seop Bae <k@acr.kr>
scaledBound(30)
scaledBound(35)
scaledBound(40)
scaledBound(45)
scaledBound(50)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.