ss2x2ci: Sample size using a confidence interval of previous 2x2 study

View source: R/ss2x2ci.R

ss2x2ciR Documentation

Sample size using a confidence interval of previous 2x2 study

Description

It calculates sample size for the bioequivalence test on ratio using a confidence interval of previous 2x2 study.

Usage

ss2x2ci(n1, n2, LL, UL, Alpha = 0.1)

Arguments

n1

Subject count of group 1

n2

Subject count of group 2

LL

Lower limit of the confidence interval of geometric mean ratio (Test/Reference)

UL

Upper limit of the confidence interval of geometric mean ratio (Test/Reference)

Alpha

Alpha level. This means (1 - alpha/2)*100 % confidence interval is given

Details

It calculates sample size (n per group) from the confidence interval (LL, UL) with Alpha for bioequivalence test.

Value

Returns a matrix with the sample size (n per group) and the achieved power (%) at the given n1, n2, each evaluated for True Ratio = 1 and True Ratio = point estimate.

Author(s)

Kyun-Seop Bae <k@acr.kr>

Examples

ss2x2ci(12, 13, 0.85, 1.11) 

BE documentation built on July 29, 2026, 5:07 p.m.