test2x2: Bioequivalence test for a variable of a 2x2 study

View source: R/test2x2.R

test2x2R Documentation

Bioequivalence test for a variable of a 2x2 study

Description

It performs conventional bioequivalence test for 2x2 study. Basic assumption is that the variable is distributed as a log-normal distribution. This is SAS PROC GLM style. If you want PROC MIXED style use nlme::lme.

Usage

test2x2(bedata, Var)

Arguments

bedata

Data table name. This should have at least the following columns and a variable column to be tested. Var column values should be all positive values.

 GRP : Group or Sequence, 'RT' or 'TR'
 PRD : Period, 1 or 2
 SUBJ : Subject ID
 TRT : Treatment or Drug, 'R' or 'T'
Var

Variable to be tested. This should be one of the column names in bedata table. Usually 'AUClast' or 'Cmax'

Details

It tests Var variable equivalency from a 2x2 study. Current regulatory requirement is that the 90% confidence interval of geometric mean ratio (Test/Reference) should be within [0.8, 1.25].

The model is log(Var) ~ GRP/SUBJ + PRD + TRT, and it is fitted with the sasLM package. The analysis of variance uses Type III sums of squares from T3test, where GROUP (sequence) is tested against SUBJECT(GROUP) and every other term against the residual mean square, as SAS PROC GLM with a RANDOM statement does. The geometric least square means come from LSM and the confidence interval from CIest.

Value

Analysis of Variance (log scale)

Analysis of Variance in log scale, with the columns Df, Sum Sq, Mean Sq, F value, and Pr(>F)

Between and Within Subject Variability

Variance in log scale and coefficient of variance in original scale

Least Square Means (geometric mean)

Geometric means

90% Confidence Interval of Geometric Mean Ratio (T/R)

90% confidence interval of geometric mean ratio (T/R)

Sample Size

Sample size for the replication of this study

Author(s)

Kyun-Seop Bae <k@acr.kr>

See Also

T3test, LSM, CIest

Examples

test2x2(NCAResult4BE, "AUClast")
test2x2(NCAResult4BE, "Cmax")

BE documentation built on July 29, 2026, 5:07 p.m.